//***************************************************************************

#import <Cocoa/Cocoa.h>

//***************************************************************************

@interface NSObject (PerformOnMainThread)

/// Similar to performSelectorOnMainThread:withObject:waitUntilDone:, but also permits including a second argument in the performed message.
- (void)performSelectorOnMainThread:(SEL)aSelector
						  withObject:(id)argument1
						  withObject:(id)argument2
					   waitUntilDone:(BOOL)wait;

/// Similar to performSelectorOnMainThread:withObject:waitUntilDone:, but also returns the result from the performed method.
/** Methods with a void return type will have an NSNull object returned, and methods with a BOOL or char return type with have an NSNumber object returned.  No other return types are currently supported at the moment! */
- (id)performSelectorOnMainThread:(SEL)aSelector
					   withObject:(id)argument1;

/// Similar to performSelectorOnMainThread:withObject:waitUntilDone:, but also returns the result from the performed method.
/** Methods with a void return type will have an NSNull object returned, and methods with a BOOL or char return type with have an NSNumber object returned.  No other return types are currently supported at the moment! */
+ (id)performSelectorOnMainThread:(SEL)aSelector
					   withObject:(id)argument1;

/// Similar to performSelectorOnMainThread:withObject:withObject:waitUntilDone:, but also returns the result from the performed method.
/** Methods with a void return type will have an NSNull object returned, and methods with a BOOL or char return type with have an NSNumber object returned.  No other return types are currently supported at the moment! */
- (id)performSelectorOnMainThread:(SEL)aSelector
					   withObject:(id)argument1
					   withObject:(id)argument2;

/// Performs the selector on a new background thread, and runs the default run loop run until the method call returns.
/** This method can be useful for performing relatively simple tasks that won't block the UI. */
- (id)performSelectorOnBackgroundThread:(SEL)aSelector
							 withObject:(id)argument1
							 withObject:(id)argument2;

/// Invokes the given invocation with the target set to the receiver.
- (void)performInvocation:(NSInvocation*)anInvocation;

@end

//***************************************************************************
