//***************************************************************************

// Copyright (C) 2008 Realmac Software Ltd
// 
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject
// to the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR
// ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
// CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

//***************************************************************************

#import <Cocoa/Cocoa.h>

#import <RMKit/RMActivity.h>
#import <RMKit/RMActivityView.h>
#import <RMKit/RMProgressIndicator.h>

//***************************************************************************

@interface NSObject (RMActivityInterfaceDelegate)

- (NSString*)localisedProgressTextFormatString;
- (NSString*)localisedActivityTitle;

- (void)activityInterfaceWillClose:(NSNotification*)notification;

- (BOOL)activityInterfaceCancelEnabled;
- (void)activityInterfaceCancelled;

- (CGFloat)activityInterfaceProgressBarCurrentValue;
- (CGFloat)activityInterfaceProgressBarMaximumValue;

- (NSString*)activityInterfaceLocalisedFinishedSuccessfullyText;
- (NSString*)activityInterfaceLocalisedFinishedWithErrorsText;
- (NSString*)activityInterfaceLocalisedFinishedDueToCancellationText;

- (NSString*)activityInterfaceFinishedTaskName;

// Implement one of these two
- (NSAttributedString*)activityInterfaceFinishedTaskDetailedAttributedString;
- (NSString*)activityInterfaceFinishedTaskDetailedString;

// Triggered when an operation has been clicked on
- (void)didClickOnOperation;

@end

//***************************************************************************

@interface RMActivityInterface : NSViewController
{
	IBOutlet RMActivityView*		activityView;
	IBOutlet NSObjectController*	selfController;
	
	BOOL							displayFinishedActivities;	// unused right now
	
	__weak id						delegate;
	
	BOOL							userHasMadeASelectionInOutlineView;
	
	RMFakeOperation*				finishedActivityInformation;
	NSMutableArray*					_observedOperations;
}

+ (RMActivityInterface*)activityInterfaceWithDelegate:(id)delegate;
+ (RMActivityInterface*)activityInterfaceWithOperations:(NSArray*)operations delegate:(id)delegate;

- (RMActivityInterface*)initWithDelegate:(id)aDelegate;
- (RMActivityInterface*)initWithOperations:(NSArray*)operations delegate:(id)aDelegate;

- (void)uninit;

- (void)observeOperation:(NSOperation*)operation;
- (void)observeOperations:(NSArray*)operations;

- (id)delegate;

- (BOOL)allActivitiesFinished;

- (NSString*)localisedProgressText;

@property (readonly, retain) NSMutableArray* observedOperations;

@end

//***************************************************************************

//@interface RMActivity
