//***************************************************************************

// Copyright (C) 2008 Realmac Software Ltd
// 
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject
// to the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR
// ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
// CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

//***************************************************************************

#import <AppKit/AppKit.h>
#import <QuartzCore/CoreAnimation.h>

#import "RMActivity.h"

//***************************************************************************

#define CELL_SIZE 128

/* useful color values to have around */
enum colors
{
	C_WHITE,
	C_BLACK,
	C_GRAY,
	C_LIGHT_GRAY,
	C_TRANSPARENT,
	C_TRANSLUCENTBLACK,
	C_COUNT
};

static const CGFloat colorValues[C_COUNT][4] =
{
{1.0, 1.0, 1.0, 1.0},
{0.0, 0.0, 0.0, 1.0},
{1.0, 1.0, 1.0, 0.5},
{1.0, 1.0, 1.0, 0.1},
{0.0, 0.0, 0.0, 0.0},
{0.0, 0.0, 0.0, 0.8}
};

@class CALayer, CATextLayer, CAScrollLayer, SpinnerLayer;

@interface RMActivityView : NSView {
	CALayer				*rootLayer;
	CAScrollLayer		*bodyLayer;
	CATextLayer			*localizedDescriptionLayer;
	CATextLayer			*progressTextLayer;
	//	CATextLayer			*localizedDetailedDescriptionLayer;
	CATransform3D		sublayerTransform;
	__strong CGImageRef shadowImage;
	NSDictionary		*textStyle;

	CALayer				*progressIndicatorLayer;
	double				_progressIndicatorValue;

	NSMapTable*			_CGImageCache; //< Cache of an operation's NSImage -> CGImageRef
	
	CGSize operationImageSize;
	int totalOperationImages, highlightedOperationImageIndex;
	
	__strong CFMutableDictionaryRef layerDictionary;	/* operation -> layer*/
	
	// Target/Selector
	__weak id	_target;
	SEL _action;
}

- (id)initWithFrame:(NSRect)frameRect;

- (void)scrollToOperation:(RMOperation *)operation;

- (void)addOperation:(RMOperation *)operation;

- (void)updateProgressText:(NSString *)progressText;

/// This value is bounded between [0.0, 1.0].
@property double progressIndicatorValue;

@property (assign) __weak id target;	// Note: this has assign semantics, not retain semantics!  (like NSControl target)
@property SEL action;

@end

//***************************************************************************
