//***************************************************************************

// Copyright (C) 2004-2007 Realmac Software Ltd
//
// These coded instructions, statements, and computer programs contain
// unpublished proprietary information of Realmac Software Ltd
// and are protected by copyright law. They may not be disclosed
// to third parties or copied or duplicated in any form, in whole or
// in part, without the prior written consent of Realmac Software Ltd.

//***************************************************************************

#import <Cocoa/Cocoa.h>
#import <Quartz/Quartz.h>

#import "RWDocument.h"
#import "RWPhotoInfoImageView.h"

//***************************************************************************

@class RBSplitView;
@class RWAddPageSheetController;
@class RWExporter;
@class RMFolderWatcher;
@class RWHTMLView;
@class RWPage;
@class RWPageAssetTableView;
@class RWPageAttributes;
@class RWPageTree;
@class RWPhotoInfoImageView;
@class RWPlugin;
@class RWProgressController;
@class RWPublishingController;
@class RWSiteLayout;
@class RWSplitView;
@class RWTextView;
@class RWTheme;
@class RWThemeInspectorController;
@class RWThemeMatrix;
@class WebView;
@class RWThemeView;
@class RWDocumentModel;
@class RWDocumentPluginProxy;
@class RWThemeBrowserController;
@class RWTextAttachment;
@class QSBorderlessWindow;

//***************************************************************************

@interface MyDocument : RWDocument<RWPhotoInfoImageViewDelegate>
{
	NSURL* _urlToLoad; // Transient

    IBOutlet NSView *pluginArea;
	IBOutlet NSView *editPreviewCodeView;
	IBOutlet NSTabView *inspectorTabView;
	IBOutlet NSTabView *inspectorPageSettingsTabView;
	IBOutlet NSTabView *inspectorSiteSettingsTabView;

    IBOutlet NSOutlineView *pageTable;
	
	IBOutlet NSView *_sourceListPlaceholderView;
	IBOutlet NSView *_sourceListView;
	IBOutlet NSView *_contentPlaceholderView;
	IBOutlet NSView *_contentView;
	
	// Add Page Sheet
	IBOutlet NSMenu *_addPagePopupMenu;
	RWAddPageSheetController *_addPageSheetController;
	IBOutlet NSButton *_bigOrSmallIconsCheckbox;

	IBOutlet NSObjectController *documentController;
    IBOutlet NSArrayController *pagesController;
    IBOutlet NSArrayController *themesController;
	
	//Page Inspector Buttons
	IBOutlet id inspectorGeneralButton;
	IBOutlet id inspectorSidebarButton;
	IBOutlet id inspectorAdvancedButton;
	IBOutlet id inspectorCodeButton;
	IBOutlet id inspectorThemeStylesButton;
	IBOutlet id inspectorPageSettingsButton;
	IBOutlet id inspectorPageSettingsDefaultView;	// Note: This is explicitly retained, see comment in -awakeFromNib for why.
	id inspectorPageSettingsContentView;
	
	//Site Inspector
	IBOutlet NSPanel *siteSetupPanel;
	IBOutlet NSView *siteSetupView;
	IBOutlet NSView *pageTemplateView;
	
	IBOutlet NSButton *siteInspectorSiteSetup;
	IBOutlet NSButton *siteInspectorPageTemplate;    
	IBOutlet NSButton *siteInspectorPreview;  
	IBOutlet NSButton *siteInspectorPublishing;  

	// BUTTON
	IBOutlet NSButton *pageTableResizerButton;
    IBOutlet id pageTableAddButton;
    IBOutlet id pageTableRemoveButton;
    IBOutlet id pageTableActionButton;
	IBOutlet id publishButton;
	IBOutlet id editButton;
	IBOutlet id previewButton;
	IBOutlet id themeButton;
	IBOutlet id codeButton;
	IBOutlet id pageInfoButton;
	
	IBOutlet id pageSettingsButton;
	IBOutlet id siteSettingsButton;
	
    IBOutlet id webView;
    
	//Theme Search PopUp Window
	IBOutlet QSBorderlessWindow *themeSearchWindow;
	IBOutlet NSButton *themeSearchButton;
	IBOutlet NSImageView *themeSearchImage;
	
	// PUBLISH
	IBOutlet id publishSheet;
	IBOutlet id publishMember;
	IBOutlet id publishPassword;
	IBOutlet id publishExport;
	
	// Themes drawer
	//IBOutlet id themesInspector; //New in 3.5
	//IBOutlet id themesDrawer;
	//IBOutlet id themesMatrixView;
	
	// Info window
	IBOutlet RWPhotoInfoImageView* infoImageView;
	
	// QC Placholder
	IBOutlet QCView *welcomeQuartzComposition;
	
	// Placeholder
	IBOutlet NSView *pagePlaceholder;
	IBOutlet WebView *pagePlaceholderWebView;
	
	// Export accessory view
	IBOutlet NSView *exportPanelAccessoryView;
	
	// Page info
	IBOutlet NSPanel*  pageInfoPanel;
	IBOutlet NSWindow* pagePropertySelectionWindow;
	IBOutlet NSWindow* pageSettingsSelectionWindow;

	// Preview Spinner
	IBOutlet NSProgressIndicator* previewSpinner;
	IBOutlet NSTextField* previewStatus;
	
	//IBOutlet NSPopUpButton* previewAfterExportHandlerMenu;
	
	//IBOutlet RWThemeMatrix* themeMatrix;
	//IBOutlet RWThemeView *themeView;
	IBOutlet NSScrollView *_themeBrowser;
	IBOutlet RWThemeBrowserController *_themeBrowserController;
	
	IBOutlet RBSplitView *_mainSplitView;
	IBOutlet RWSplitView *contentSplitView;

	IBOutlet RWHTMLView *untidiedHTMLTextView;

	IBOutlet NSView *codeView;

	RWPublishingController* publishingController;
	
	RWProgressController* _progressController;
	
	IBOutlet RWPhotoInfoImageView* faviconView;
	IBOutlet RWPhotoInfoImageView* webClipIconView;
	
	IBOutlet RWPageAssetTableView* pageAssetTableView;
	
	IBOutlet id pageThemePopUpButton;
	NSMenu* _pageThemeMenu;

	IBOutlet NSPanel* mediaInspector;
	IBOutlet NSView* mediaInspectorImageView;
	IBOutlet NSView* mediaInspectorMovieView;
	IBOutlet NSView* mediaInspectorTextView;
	
	IBOutlet RWThemeInspectorController* themeInspectorController;

	RMFolderWatcher* _currentThemeFileWatcher;
	NSTimer* _currentThemeFileWatcherTimer;
	
	NSTimer* _webViewUpdateTimer;
	
	IBOutlet RWHTMLView* pageInspectorSidebarHTML;
	IBOutlet RWTextView* pageInspectorSidebarStyled;
	
	IBOutlet NSBox* pageInspectorSiteSidebarSuperview;
	IBOutlet id pageInspectorSiteSidebarHTML;
	IBOutlet id pageInspectorSiteSidebarStyled;
	
	IBOutlet id errorsAndWarningsPanel;
	IBOutlet id errorsAndWarningsHTMLView;
	IBOutlet id errorsAndWarningsTableView;
	
	IBOutlet NSButtonCell* pageThemeIsMasterStyleRadioButton;
	
	// Yecch, these things should really be moved out to a separate class for RW37...
	IBOutlet NSPanel* imageNormalisationPanel;
	IBOutlet NSButton* imageNormalisationDefaultButton;
	IBOutlet NSTextField* imageNormalisationInformationText;
	IBOutlet NSComboBox* imageNormalisationUnsupportedPluginsBox;
	IBOutlet NSTextField* imageNormalisationUnsupportedPluginsInformation;
		
	NSInteger selectedItem;
	NSInteger previouslySelectedItem;
	NSInteger _selectedItemBeforeToggleSetup;	
	NSString* _previewDirectory;
	NSMutableArray* _exportCompletionActions;
	NSString* _exportMode;
	RWPage* _currentlySelectedPage;
	RWExporter* _exporter;
	RWSiteLayout* _siteLayout;
	RWPage* _lastLivePreviewedPage;
	NSMutableDictionary* _currentPageSettings;
	NSMutableArray* _currentPages;
	NSString* _saveToFileName;
	BOOL _exportAll;
	BOOL _publishAll;
	BOOL _useAsDefaultExportFolder;
	BOOL _loadCameFromDocument;
	BOOL _watchCurrentThemeFiles;
	BOOL _themeMatrixVisible;
	BOOL _showingCodeView;
	BOOL _normalisingImages;
	BOOL _showThemeSearch;
	
	// These are created to handle the animation of the plugin/preview tabview sliding out of the window
	NSView *tabViewPlaceholder;
	NSImageView *shadow;
	NSView *shadowView;
	
	RWTextAttachment* _currentMedia; // Transient
	
	IBOutlet NSToolbarItem* previewToolbarItem;
}

- (NSString*)documentPath;

- (NSString*)siteTitle;
- (void)setSiteTitle:(NSString*)title;
- (BOOL)useSiteTitle;
- (void)setUseSiteTitle:(BOOL)flag;

- (NSString*)siteCopyright;
- (void)setSiteCopyright:(NSString*)copyright;
- (BOOL)useSiteCopyright;
- (void)setUseSiteCopyright:(BOOL)flag;

- (NSString*)siteEmail;
- (void)setSiteEmail:(NSString*)email;
- (BOOL)addCopyrightMailto;
- (void)setAddCopyrightMailto:(BOOL)flag;
- (BOOL)obfuscateSiteEmailAddress;
- (void)setObfuscateSiteEmailAddress:(BOOL)flag;

- (NSString *)siteGoogleAnalyticsCode;
- (void)setSiteGoogleAnalyticsCode:(NSString *)googleAnalyticsCode;

- (NSString*)siteContactText;
- (void)setSiteContactText:(NSString*)text;

- (NSString*)siteSlogan;
- (void)setSiteSlogan:(NSString*)slogan;
- (BOOL)useSiteSlogan;
- (void)setUseSiteSlogan:(BOOL)flag;

- (NSImage*)siteLogo;
- (void)setSiteLogo:(NSImage*)logo;

- (NSString*)siteLogoFilename;
- (void)setSiteLogoFilename:(NSString*)file;

- (NSData*)siteLogoData;
- (void)setSiteLogoData:(NSData*)data;

- (BOOL)useSiteLogo;
- (void)setUseSiteLogo:(BOOL)flag;

- (BOOL)useFavicon;
- (void)setUseFavicon:(BOOL)flag;

- (NSData*)faviconData;
- (void)setFaviconData:(NSData*)data;

- (BOOL)useWebClipIcon;
- (void)setUseWebClipIcon:(BOOL)flag;

- (NSData*)webClipIconData;
- (void)setWebClipIconData:(NSData*)data;

- (NSString*)siteDefaultExportDestination;
- (void)setSiteDefaultExportDestination:(NSString*)path;

- (NSString*)siteDefaultPublishDestination;
- (void)setSiteDefaultPublishDestination:(NSString*)path;

- (RWPageAttributes*)defaultPageAttributes;
- (void)setDefaultPageAttributes:(RWPageAttributes*)attrs;

- (BOOL)showBreadcrumbTrail;
- (void)setShowBreadcrumbTrail:(BOOL)flag;

- (BOOL)previewInPlace;

- (BOOL)previewAfterExportRelativeToBaseURL;
- (void)setPreviewAfterExportRelativeToBaseURL:(BOOL)flag;

- (NSInteger)commonFileConsolidationMode;
- (void)setCommonFileConsolidationMode:(NSInteger)mode;

- (BOOL)processPHP;
- (void)setProcessPHP:(BOOL)flag;

- (id)manifestForKey:(NSString*)key;
- (void)setManifest:(id)manifest forKey:(NSString*)key;

- (NSString*)guid DEPRECATED_ATTRIBUTE;

- (RMFolderWatcher*)currentThemeFileWatcher;
- (void)setCurrentThemeFileWatcher:(RMFolderWatcher*)watcher;

- (BOOL)watchCurrentThemeFiles;
- (void)setWatchCurrentThemeFiles:(BOOL)flag;

- (BOOL)showTidiedCode;
- (void)setShowTidiedCode:(BOOL)flag;

- (void)setImageExportFormat:(NSString*)format;
- (void)setImageExportQuality:(NSString*)quality;

enum {
	kPageInspectorPageMode,
	kPageInspectorSiteMode,
	kPageInspectorCurrentMode
};
- (void)showPageInfoPanel:(RWPage*)page mode:(NSInteger)mode;
- (void)hidePageInfoPanel;
- (void)previewPageInExternalHandler:(NSDictionary*)data;

- (void)clearPageManifest:(RWPage*)page;

- (void)toggleThemesDrawer:(id)sender;

/// Informs the document that the user wants to add or replace a page.
/** If the user selects more then one plugin when replacing a page the 1st plugin will be used for the replace operation and the rest of the selected plugins will be added after it. */
- (void)userSelectedPlugins:(NSMutableArray *)plugins isReplacingPage:(BOOL)isReplacingPage;

- (IBAction)showPluginSetupSheet:(id)sender;
- (IBAction)togglePluginSetupSheet:(id)sender;
- (IBAction)endSheet:(id)sender;
- (IBAction)launchHelp:(id)sender;

- (NSArray*)allPages;
- (void)setAllPages:(NSArray *)pages; // make private

- (RWPage*)com_rwrp_duplicatePage:(RWPage*)page document:(MyDocument*)document title:(NSString*)title;
- (void)duplicatePage:(RWPage*)page;

- (RWPage*)index;
- (void)setIndex:(RWPage*)index;

- (NSString*)siteIndexFilename;

- (NSString*)siteBaseURL;
- (NSString*)siteBaseURLEscaped;
- (void)setSiteBaseURL:(NSString*)url;

- (NSString*)siteIndexFilenameOverriddenForPage:(RWPage*)page;

- (RWTheme *)theme;
- (void)setTheme:(RWTheme *)theme;
- (NSArray *)themes;

- (NSMutableDictionary*)currentPageSettings;
- (void)setCurrentPageSettings:(NSMutableDictionary*)settings;

- (NSMutableArray*)currentPages;
- (void)setCurrentPages:(NSMutableArray*)pages;

- (NSArray*)plugins;

- (BOOL)checkSiteDefaultExportDestination;
- (NSString*)pageLocationInDefaultExportLocation:(RWPage*)page;

- (void)exportPageToDefaultLocation:(RWPage*)page andChildren:(BOOL)descend;
- (void)publishPageToDefaultLocation:(RWPage*)page andChildren:(BOOL)descend;

- (void)pageTableSelectionDidChange;

- (RWPage*)pageFromUniqueID:(NSString*)uniqueID;
- (RWPage *)pageFromUniqueID:(NSString *)identifier topLevelOnly:(BOOL)top;

- (NSString*)pathFromPage:(id)pageID to:(id)pageID2;

- (NSString*)pageFilesFolderName:(id)pageID;

- (void)clearPublishingCache;

- (IBAction)togglePageTableIconSize:(id)sender;
- (IBAction)showAddPagePanel:(id)sender;
- (IBAction)showReplacePagePanel:(id)sender;
- (IBAction)addPageViaMenu:(id)sender;
- (IBAction)removeSelectedPage:(id)sender;
- (IBAction)themeMatrixSelectionDidChange:(id)sender;
- (IBAction)showHideThemeDrawer:(id)sender;
- (IBAction)showHideThemeSearch:(id)sender;

- (IBAction)togglePHPButton:(id)sender;
- (IBAction)toggleTidyCodeButotn:(id)sender;

- (void)themeTableSelectionDidChange;

- (void)export:(id)sender checkForUnchanged:(BOOL)checkForUnchanged;

- (void)updateThemes;
- (void)updateTitle:(id)sender;

// Utility
- (NSString*)previewDirectory;

- (BOOL)busy;

- (NSMenu*)pageThemeMenu;

- (RWPage*)currentlySelectedPage;
- (void)setCurrentlySelectedPage:(RWPage*)page;

- (void)cleanupWebViewUpdateTimer;

- (NSMutableSet*)defaultSiteVariationsFlags;
- (NSMutableDictionary*)defaultSiteColourVariations;

- (RWTheme *)selectedTheme;
- (void)selectTheme:(RWTheme *)theme;
- (void)selectThemeIndex:(int)index;

@property (copy) NSURL* urlToLoad;
@property (retain) RWSiteLayout* siteLayout;

@end

@interface MyDocument (ImageNormalisationSheet)

- (IBAction)imageNormalisationSheetCancel:(id)sender;
- (IBAction)imageNormalisationSheetNormalise:(id)sender;

@end


BOOL AddingPagesToDocumentIsCool(MyDocument* document, BOOL displayWarning);

extern NSString* const kRWCurrentMediaChangedNotification;
extern NSString* const kRWDoubleClickedMediaNotification;

extern const NSInteger kPageInspectorThemeDefaultMenuItemTag;
extern const NSInteger kPageInspectorThemeNotDefaultMenuItemTag;
