//
//  RWPage.h
//  RapidWeaver
//
//  Created by Daniel Counsell on Wed Jun 16 2004.
//  Copyright (c) 2004 Realmac Software. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import <RMKit/RMKit.h>
#import <RWKit/RWKit.h>

#import "RW4Page.h"
#import "RWPageStyles.h"
#import "RWPageAttributes.h"

@class RWTheme;
@class MyDocument;
@protocol RWPluginProtocol;

@interface RWPage : RW4Page<NSCoding>
{
	// Transient ivars
	NSInteger _savedIndex;
    NSString *_pluginPath;
	NSMutableArray* _errorsAndWarnings;
	NSString* _untidiedHTML;
	NSString* _tidiedHTML;
}

- (id)initWithPluginClass:(Class)pluginClass document:(MyDocument *)document;
- (id)initWithPlugin:(id<RWPluginProtocol>)plugin document:(MyDocument*)document;

- (MyDocument*)document;
- (void)setDocument:(MyDocument*)document;

- (NSString*)themeName;
- (void)setThemeName:(NSString*)name;
- (RWTheme*)theme;
- (BOOL)pageUsesDefaultSiteTheme;

- (NSString*)mostRecentlySelectedStyleName;
- (void)setMostRecentlySelectedStyleName:(NSString*)styleName;

- (NSInteger)savedIndex;
- (void)setSavedIndex:(NSInteger)i;

- (NSString*)title;
- (void)setTitle:(NSString*)title;

- (NSString*)buttonName;
- (void)setButtonName:(NSString*)name;

- (NSString*)type;

- (RWPageAttributes*)attributes;
- (void)setPageAttributes:(NSMutableDictionary*)attributes;
- (void)setPageAttributesFromRWPageAttributes:(RWPageAttributes*)attributes;
- (NSMutableDictionary*)attributesFromDictionary;

- (NSView *)view;

- (RWPage*)parent;
- (void)setParent:(RWPage*)parent;

- (void)addChild:(RWPage*)child;
- (void)removeChild:(RWPage*)child andChildren:(BOOL)removeChildren;

- (NSArray*)allChildren;

- (NSInteger)countChildren;

- (NSInteger)childIndex:(RWPage*)child;
- (void)setChildIndex:(RWPage*)child index:(NSUInteger)index;

- (RWPage*)pageFromUniqueID:(NSString*)uniqueID;
- (BOOL)containsPage:(RWPage*)page;

- (BOOL)isDescendedFrom:(RWPage*)page;
- (BOOL)isIndex;

- (NSString*)position;
- (NSInteger)hierarchyDepth;
- (NSInteger)pathDepth;
- (NSInteger)depth;	// Note: same as -pathDepth, here for backwards compatibility

- (NSDictionary*)pageAssets;
- (void)setPageAssets:(NSMutableDictionary*)assets;

- (NSDictionary*)manifest;
- (void)setManifest:(NSDictionary*)manifest;

- (NSArray*)errorsAndWarnings;
- (void)setErrorsAndWarnings:(NSArray*)errors;

- (void)resetErrorsAndWarnings;
- (void)resetErrorsAndWarnings_;
- (void)appendErrorsAndWarnings:(NSArray*)errors;
- (void)appendErrorsAndWarnings_:(NSArray*)errors;

- (NSString*)untidiedHTML;
- (void)setUntidiedHTML:(NSString*)html;
- (void)setUntidiedHTML_:(NSString*)html;

- (NSString*)tidiedHTML;
- (void)setTidiedHTML:(NSString*)html;
- (void)setTidiedHTML_:(NSString*)html;

- (BOOL)isExternalPage;
- (NSString*)externalPageURL;
- (NSString*)externalPageTarget;

- (BOOL)enabled;

- (NSMutableSet*)currentVariationsFlags:(BOOL*)siteFlags;
- (NSMutableDictionary*)currentColourVariations;

- (BOOL)hasOptionsAndConfigurationView;

- (NSImage *)icon;

@end
